//-------------------------------------------------------------------------
/* Data file structures 
	CDataFileInterface - set of virtual methods as template for actual file handlers
	CQDSFInterface - CDataFileInterface for QDF+QSF file type (only filetype currently)
*/

//----- disk file interface base class which is a template for specific data file types.
class CDataFileInterface { 
	public : 
		CString m_cFileName;
		
		virtual bool Open( const char * pchFileName, double * pdScaling, double * pdSampling, 
						CDataConfigure * pConfig, CItemArray * paSegments, CItemArray * paLists );
		virtual bool SaveData( const char * pchFileName, double dSampling, double dScaling,
					CDataConfigure * pConfig, CItemArray * paSegments, CItemArray * paLists );
		virtual bool CreateData( const char * pchFileName, double dSampling, double dScaling,
					CDataConfigure * pConfig, CItemArray * paSegments, CItemArray * paLists );
		virtual bool Close( ) ;
		virtual bool LoadSegmentData( CSegment * pSeg );
		virtual bool SaveSegmentData( CSegment * pSeg );
	};


class CQDSFInterface : public CDataFileInterface {		//-- Interface to QDF+QSF file type
	public : 
		double m_dFileScaling;
		double * m_adScaling;		// array of scalings copy from channels for convenience
		void CopyChannelScaling( CItemArray * paChannels );
		bool CalculateScaling( CItemArray * paChannels, CItemArray * paSegments, double dScaling );
		
	public :
		CQDSFFile m_oQDSF;			// Interface to actual file and handle
		//----- Open an existing .qdf file and fill in the channels and segments arrays
		bool Open( const char * pchFileName, double * pdSampling, double * pdScaling, 
						CDataConfigure * pConfig, CItemArray * paSegments, CItemArray * paLists ) ;
		bool SaveData( const char * pchFileName, double dSampling, double dScaling,
					CDataConfigure * pConfig, CItemArray * paSegments, CItemArray * paLists );
		bool CreateData( const char * pchFileName, double dSampling, double dScaling,
					CDataConfigure * pConfig, CItemArray * paSegments, CItemArray * paLists );
		bool Close( ) ;
		bool LoadSegmentData( CSegment * pSeg );
		bool SaveSegmentData( CSegment * pSeg );
	};


